@@ -18,6 +18,8 @@ from typing import (
 )
 
 import torch.utils.data.dataset as torch_dataset
+from pytorch_lightning.core.mixins import HyperparametersMixin
+from tqdm import tqdm
 
 from pytorch_ie.core.document import Annotation, Document
 from pytorch_ie.core.hf_hub_mixin import PyTorchIETaskmoduleModelHubMixin
@@ -144,6 +146,7 @@ class TaskEncodingSequence(
 class TaskModule(
     ABC,
     PyTorchIETaskmoduleModelHubMixin,
+    HyperparametersMixin,
     Registrable,
     Generic[
         DocumentType,
@@ -154,35 +157,99 @@ class TaskModule(
         TaskOutput,
     ],
 ):
+    PREPARED_ATTRIBUTES: List[str] = []
+
     def __init__(self, encode_document_batch_size: Optional[int] = None, **kwargs):
         super().__init__(**kwargs)
         self.encode_document_batch_size = encode_document_batch_size
 
-    def _config(self) -> Dict[str, Any]:
-        config = dict(self.hparams)
-        this_class = self.__class__
-        registered_name = TaskModule.registered_name_for_class(this_class)
-        config["taskmodule_type"] = (
-            registered_name if registered_name is not None else this_class.__name__
+    @property
+    def is_prepared(self):
+        """
+        Returns True, iff all attributes listed in PREPARED_ATTRIBUTES are set.
+        Note: Attributes set to None are not considered to be prepared!
+        """
+        return all(
+            getattr(self, attribute, None) is not None for attribute in self.PREPARED_ATTRIBUTES
         )
-        return config
+
+    @property
+    def prepared_attributes(self):
+        if not self.is_prepared:
+            raise Exception("The taskmodule is not prepared.")
+        return {param: getattr(self, param) for param in self.PREPARED_ATTRIBUTES}
+
+    def _prepare(self, documents: Sequence[DocumentType]):
+        """
+        This method needs to set all attributes listed in PREPARED_ATTRIBUTES.
+        """
+        pass
+
+    def _post_prepare(self):
+        """
+        Any code to do further one-time setup, but that requires the prepared attributes.
+        """
+        pass
+
+    def _assert_is_prepared(self, msg: Optional[str] = None):
+        if not self.is_prepared:
+            attributes_not_prepared = [
+                param for param in self.PREPARED_ATTRIBUTES if getattr(self, param, None) is None
+            ]
+            raise Exception(
+                f"{msg or ''} Required attributes that are not set: {str(attributes_not_prepared)}"
+            )
 
     def prepare(self, documents: Sequence[DocumentType]) -> None:
+        if self.is_prepared:
+            if len(self.PREPARED_ATTRIBUTES) > 0:
+                msg = "The taskmodule is already prepared, do not prepare again."
+                for k, v in self.prepared_attributes.items():
+                    msg += f"\n{k} = {str(v)}"
+                logger.warning(msg)
+        else:
+            self._prepare(documents)
+            self._assert_is_prepared(
+                msg="_prepare() was called, but the taskmodule is not prepared."
+            )
+        self._post_prepare()
         return None
 
+    def _config(self) -> Dict[str, Any]:
+        config = super()._config() or {}
+        config[self.config_type_key] = TaskModule.name_for_object_class(self)
+        # add all hparams
+        config.update(self.hparams)
+        # add all prepared attributes
+        config.update(self.prepared_attributes)
+        return config
+
+    @classmethod
+    def _from_pretrained(
+        cls,
+        *args,
+        **kwargs,
+    ):
+        taskmodule = super()._from_pretrained(*args, **kwargs)
+        taskmodule._post_prepare()
+        return taskmodule
+
     def batch_encode(
-        self, documents: Union[Sequence[DocumentType], Dataset], encode_target: bool
+        self,
+        documents: Union[Sequence[DocumentType], Dataset],
+        encode_target: bool,
+        show_progress: bool = False,
     ) -> Tuple[
         Sequence[TaskEncoding[DocumentType, InputEncoding, TargetEncoding]], Sequence[DocumentType]
     ]:
         ## TODO: revisit the assumption that encode_target=True always implies that
         ## is_training=True
         task_encodings, documents_in_order = self.encode_inputs(
-            documents, is_training=encode_target
+            documents, is_training=encode_target, show_progress=show_progress
         )
 
         if encode_target:
-            task_encodings = self.encode_targets(task_encodings)
+            task_encodings = self.encode_targets(task_encodings, show_progress=show_progress)
         return task_encodings, documents_in_order
 
     def _encoding_iterator(
@@ -190,19 +257,30 @@ class TaskModule(
         documents: Iterable[DocumentType],
         encode_target: bool,
         batch_size: Optional[int] = None,
+        show_progress: bool = False,
     ) -> Iterator[TaskEncoding[DocumentType, InputEncoding, TargetEncoding]]:
         document_batch = []
+        if show_progress and batch_size is not None:
+            logger.warning(
+                "do not show document encoding progress because we encode lazily with an iterator"
+            )
         for i, doc in enumerate(documents):
             document_batch.append(doc)
 
             if batch_size is not None and len(document_batch) >= batch_size:
                 yield from self.batch_encode(
-                    documents=document_batch[:batch_size], encode_target=encode_target
+                    documents=document_batch[:batch_size],
+                    encode_target=encode_target,
+                    show_progress=False,
                 )[0]
                 document_batch = document_batch[batch_size:]
 
         if len(document_batch) > 0:
-            yield from self.batch_encode(documents=document_batch, encode_target=encode_target)[0]
+            yield from self.batch_encode(
+                documents=document_batch,
+                encode_target=encode_target,
+                show_progress=show_progress and batch_size is None,
+            )[0]
 
     def encode(
         self,
@@ -212,6 +290,7 @@ class TaskModule(
         as_task_encoding_sequence: Optional[bool] = None,
         as_iterator: Optional[bool] = None,
         as_dataset: bool = False,
+        show_progress: bool = False,
     ) -> Union[
         Sequence[TaskEncoding[DocumentType, InputEncoding, TargetEncoding]],
         TaskEncodingSequence[
@@ -238,7 +317,10 @@ class TaskModule(
             if as_task_encoding_sequence:
                 raise ValueError(f"can not return a TaskEncodingSequence as Iterator")
             encodings_iterator = self._encoding_iterator(
-                documents=documents, encode_target=encode_target, batch_size=document_batch_size
+                documents=documents,
+                encode_target=encode_target,
+                batch_size=document_batch_size,
+                show_progress=show_progress,
             )
             if as_dataset:
                 return IterableTaskEncodingDataset(encodings=encodings_iterator)
@@ -249,9 +331,15 @@ class TaskModule(
             documents_in_order: List[DocumentType] = []
             docs_as_list = list(documents)
             bs = document_batch_size or len(docs_as_list)
-            for i in range(0, len(docs_as_list), bs):
+            for i in tqdm(
+                range(0, len(docs_as_list), bs),
+                disable=not (show_progress and document_batch_size is not None),
+                desc="encode documents",
+            ):
                 cur_task_encodings, cur_documents_in_order = self.batch_encode(
-                    documents=docs_as_list[i : i + bs], encode_target=encode_target
+                    documents=docs_as_list[i : i + bs],
+                    encode_target=encode_target,
+                    show_progress=show_progress and document_batch_size is None,
                 )
                 encodings.extend(cur_task_encodings)
                 documents_in_order.extend(cur_documents_in_order)
@@ -276,13 +364,14 @@ class TaskModule(
         self,
         documents: Union[Sequence[DocumentType], Dataset, IterableDataset],
         is_training: bool = False,
+        show_progress: bool = False,
     ) -> Tuple[
         Sequence[TaskEncoding[DocumentType, InputEncoding, TargetEncoding]],
         Sequence[DocumentType],
     ]:
         documents_in_order: List[DocumentType] = []
         task_encodings: List[TaskEncoding[DocumentType, InputEncoding, TargetEncoding]] = []
-        for document in documents:
+        for document in tqdm(documents, disable=not show_progress, desc="encode inputs"):
             # a document might be generated on the fly (e.g. with a Dataset), so we add it here
             documents_in_order.append(document)
 
@@ -316,6 +405,7 @@ class TaskModule(
     def encode_targets(
         self,
         task_encodings: Sequence[TaskEncoding[DocumentType, InputEncoding, TargetEncoding]],
+        show_progress: bool = False,
     ) -> List[TaskEncoding[DocumentType, InputEncoding, TargetEncoding]]:
         """
         Given a list of task encodings, get and assign the respective target encodings
@@ -328,7 +418,9 @@ class TaskModule(
         easily by letting encode_target() return None.
         """
         res = []
-        for task_encoding in task_encodings:
+        for task_encoding in tqdm(
+            task_encodings, disable=not show_progress, desc="encode targets"
+        ):
             target_encoding = self.encode_target(task_encoding)
             if target_encoding is not None:
                 task_encoding.targets = target_encoding
