@@ -3,7 +3,7 @@ from typing import Dict, Union
 from datasets import Split
 
 from .builder import GeneratorBasedBuilder
-from .dataset import Dataset
+from .dataset import Dataset, IterableDataset
 from .dataset_formatter import DocumentFormatter
 
 DatasetDict = Dict[Union[str, Split], Dataset]
@@ -11,6 +11,7 @@ DatasetDict = Dict[Union[str, Split], Dataset]
 __all__ = [
     "GeneratorBasedBuilder",
     "Dataset",
+    "IterableDataset",
     "DatasetDict",
     "DocumentFormatter",
 ]
