@@ -1,3 +1,12 @@
+"""
+workflow:
+    Document
+        -> (InputEncoding, TargetEncoding) -> TaskEncoding -> TaskBatchEncoding
+            -> ModelBatchEncoding -> ModelBatchOutput
+        -> TaskOutput
+    -> Document
+"""
+
 import logging
 from typing import Any, Dict, Iterator, List, Optional, Sequence, Set, Tuple, TypedDict, Union
 
@@ -6,6 +15,7 @@ import torch
 from transformers import AutoTokenizer
 from transformers.file_utils import PaddingStrategy
 from transformers.tokenization_utils_base import BatchEncoding, TruncationStrategy
+from typing_extensions import TypeAlias
 
 from pytorch_ie.annotations import BinaryRelation, LabeledSpan, MultiLabeledBinaryRelation, Span
 from pytorch_ie.core import TaskEncoding, TaskModule
@@ -17,19 +27,10 @@ from pytorch_ie.models import (
 from pytorch_ie.utils.span import get_token_slice, is_contained_in
 from pytorch_ie.utils.window import get_window_around_slice
 
-"""
-workflow:
-    Document
-        -> (InputEncoding, TargetEncoding) -> TaskEncoding -> TaskBatchEncoding
-            -> ModelBatchEncoding -> ModelBatchOutput
-        -> TaskOutput
-    -> Document
-"""
+TransformerReTextClassificationInputEncoding: TypeAlias = Dict[str, Any]
+TransformerReTextClassificationTargetEncoding: TypeAlias = Sequence[int]
 
-TransformerReTextClassificationInputEncoding = Dict[str, Any]
-TransformerReTextClassificationTargetEncoding = Sequence[int]
-
-TransformerReTextClassificationTaskEncoding = TaskEncoding[
+TransformerReTextClassificationTaskEncoding: TypeAlias = TaskEncoding[
     TextDocument,
     TransformerReTextClassificationInputEncoding,
     TransformerReTextClassificationTargetEncoding,
@@ -41,7 +42,7 @@ class TransformerReTextClassificationTaskOutput(TypedDict, total=False):
     probabilities: Sequence[float]
 
 
-_TransformerReTextClassificationTaskModule = TaskModule[
+_TransformerReTextClassificationTaskModule: TypeAlias = TaskModule[
     # _InputEncoding, _TargetEncoding, _TaskBatchEncoding, _ModelBatchOutput, _TaskOutput
     TextDocument,
     TransformerReTextClassificationInputEncoding,
@@ -51,6 +52,7 @@ _TransformerReTextClassificationTaskModule = TaskModule[
     TransformerReTextClassificationTaskOutput,
 ]
 
+
 HEAD = "head"
 TAIL = "tail"
 START = "start"
@@ -132,6 +134,8 @@ class TransformerRETextClassificationTaskModule(_TransformerReTextClassification
         TODO: add remaining parameters
     """
 
+    PREPARED_ATTRIBUTES = ["label_to_id", "entity_labels"]
+
     def __init__(
         self,
         tokenizer_name_or_path: str,
@@ -176,30 +180,7 @@ class TransformerRETextClassificationTaskModule(_TransformerReTextClassification
 
         self.argument_markers = None
 
-        if self.is_prepared():
-            self.argument_markers = _create_argument_markers(
-                # ignore typing because is_prepared already checks that entity_labels is not None
-                entity_labels=self.entity_labels,  # type: ignore
-                add_type_to_marker=self.add_type_to_marker,
-            )
-            # do not sort here to keep order from loaded taskmodule config
-            self.tokenizer.add_tokens(list(self.argument_markers.values()), special_tokens=True)
-
-    def _config(self) -> Dict[str, Any]:
-        config = super()._config()
-        config["label_to_id"] = self.label_to_id
-        config["entity_labels"] = self.entity_labels
-        return config
-
-    def is_prepared(self):
-        """
-        This should return True iff all config entries added by the _config() method are available.
-        By doing so, it marks the taskmodule ready to save with save_pretrained(), i.e. that the
-        exact same taskmodule will be produced when loaded again via from_pretrained().
-        """
-        return self.entity_labels is not None and self.label_to_id is not None
-
-    def prepare(self, documents: Sequence[TextDocument]) -> None:
+    def _prepare(self, documents: Sequence[TextDocument]) -> None:
         entity_labels: Set[str] = set()
         relation_labels: Set[str] = set()
         for document in documents:
@@ -219,18 +200,29 @@ class TransformerRETextClassificationTaskModule(_TransformerReTextClassification
         self.label_to_id = {label: i + 1 for i, label in enumerate(sorted(relation_labels))}
         self.label_to_id[self.none_label] = 0
 
-        self.id_to_label = {v: k for k, v in self.label_to_id.items()}
-
         self.entity_labels = sorted(entity_labels)
-        argument_markers = _create_argument_markers(
-            entity_labels=self.entity_labels, add_type_to_marker=self.add_type_to_marker
+
+    def _post_prepare(self):
+        self.argument_markers = _create_argument_markers(
+            # ignore typing because is_prepared already checks that entity_labels is not None
+            entity_labels=self.entity_labels,  # type: ignore
+            add_type_to_marker=self.add_type_to_marker,
         )
-        # Sort argument markers by value to ensure that added tokens are in a reproducible order.
-        # Note: To maintain backwards compatibility, the argument markers are not sorted when loading from a saved
-        # taskmodule!
-        self.argument_markers = dict(sorted(argument_markers.items(), key=lambda kv: kv[1]))
+        if not self.is_from_pretrained:
+            # Sort argument markers by value to ensure that added tokens are in a reproducible order.
+            # Note: To maintain backwards compatibility, the argument markers are not sorted when loading from a saved
+            # taskmodule!
+            self.argument_markers = dict(
+                sorted(self.argument_markers.items(), key=lambda kv: kv[1])
+            )
         self.tokenizer.add_tokens(list(self.argument_markers.values()), special_tokens=True)
 
+        self.argument_markers_to_id = {
+            marker: self.tokenizer.vocab[marker] for marker in self.argument_markers.values()
+        }
+
+        self.id_to_label = {v: k for k, v in self.label_to_id.items()}
+
     def _encode_text(
         self,
         document: TextDocument,
@@ -267,9 +259,6 @@ class TransformerRETextClassificationTaskModule(_TransformerReTextClassification
         assert (
             self.argument_markers is not None
         ), f"No argument markers available, was `prepare` already called?"
-        argument_markers_to_id = {
-            marker: self.tokenizer.vocab[marker] for marker in self.argument_markers.values()
-        }
 
         entities: Sequence[Span] = document[self.entity_annotation]
 
@@ -295,7 +284,10 @@ class TransformerRETextClassificationTaskModule(_TransformerReTextClassification
                 document=document, partition=partition, add_special_tokens=add_special_tokens
             )
 
-            for head, tail, in _enumerate_entity_pairs(
+            for (
+                head,
+                tail,
+            ) in _enumerate_entity_pairs(
                 entities=entities,
                 partition=partition,
                 relations=relations,
@@ -355,14 +347,14 @@ class TransformerRETextClassificationTaskModule(_TransformerReTextClassification
                 if head_token_slice[0] < tail_token_slice[0]:
                     assert (
                         head_token_slice[1] <= tail_token_slice[0]
-                    ), f"the head and tail entities are not allowed to overlap"
+                    ), f"the head and tail entities are not allowed to overlap in {document.id}"
                     entity_pair = (head, tail)
                     entity_slices = (head_token_slice, tail_token_slice)
                     entity_args = (HEAD, TAIL)
                 else:
                     assert (
                         tail_token_slice[1] <= head_token_slice[0]
-                    ), f"the head and tail entities are not allowed to overlap"
+                    ), f"the head and tail entities are not allowed to overlap in {document.id}"
                     entity_pair = (tail, head)
                     entity_slices = (tail_token_slice, head_token_slice)
                     entity_args = (TAIL, HEAD)
@@ -371,11 +363,11 @@ class TransformerRETextClassificationTaskModule(_TransformerReTextClassification
                 for entity, arg_name in zip(entity_pair, entity_args):
                     for pos in [START, END]:
                         if self.add_type_to_marker:
-                            markers[(arg_name, pos)] = argument_markers_to_id[
+                            markers[(arg_name, pos)] = self.argument_markers_to_id[
                                 self.argument_markers[(arg_name, pos, entity.label)]
                             ]
                         else:
-                            markers[(arg_name, pos)] = argument_markers_to_id[
+                            markers[(arg_name, pos)] = self.argument_markers_to_id[
                                 self.argument_markers[(arg_name, pos)]
                             ]
 
@@ -473,7 +465,6 @@ class TransformerRETextClassificationTaskModule(_TransformerReTextClassification
     def collate(
         self, task_encodings: Sequence[TransformerReTextClassificationTaskEncoding]
     ) -> TransformerTextClassificationModelStepBatchEncoding:
-
         input_features = [task_encoding.inputs for task_encoding in task_encodings]
 
         inputs: Dict[str, torch.Tensor] = self.tokenizer.pad(
