@@ -1,3 +1,12 @@
+"""
+workflow:
+    document
+        -> (input_encoding, target_encoding) -> task_encoding
+            -> model_encoding -> model_output
+        -> task_output
+    -> document
+"""
+
 import logging
 import re
 from typing import Any, Dict, Iterator, List, Optional, Sequence, Tuple, Union
@@ -5,6 +14,7 @@ from typing import Any, Dict, Iterator, List, Optional, Sequence, Tuple, Union
 from transformers import AutoTokenizer
 from transformers.file_utils import PaddingStrategy
 from transformers.tokenization_utils_base import TruncationStrategy
+from typing_extensions import TypeAlias
 
 from pytorch_ie.annotations import BinaryRelation, LabeledSpan, Span
 from pytorch_ie.core import Annotation, TaskEncoding, TaskModule
@@ -14,24 +24,15 @@ from pytorch_ie.models import (
     TransformerSeq2SeqModelStepBatchEncoding,
 )
 
-"""
-workflow:
-    Document
-        -> (InputEncoding, TargetEncoding) -> TaskEncoding -> TaskBatchEncoding
-            -> ModelBatchEncoding -> ModelBatchOutput
-        -> TaskOutput
-    -> Document
-"""
+TransformerSeq2SeqInputEncoding: TypeAlias = Dict[str, Sequence[int]]
+TransformerSeq2SeqTargetEncoding: TypeAlias = Dict[str, Sequence[int]]
 
-TransformerSeq2SeqInputEncoding = Dict[str, Sequence[int]]
-TransformerSeq2SeqTargetEncoding = Dict[str, Sequence[int]]
-
-TransformerSeq2SeqTaskEncoding = TaskEncoding[
+TransformerSeq2SeqTaskEncoding: TypeAlias = TaskEncoding[
     TextDocument, TransformerSeq2SeqInputEncoding, TransformerSeq2SeqTargetEncoding
 ]
-TransformerSeq2SeqTaskOutput = Sequence[Dict[str, Any]]
+TransformerSeq2SeqTaskOutput: TypeAlias = Sequence[Dict[str, Any]]
 
-_TransformerSeq2SeqTaskModule = TaskModule[
+_TransformerSeq2SeqTaskModule: TypeAlias = TaskModule[
     # _InputEncoding, _TargetEncoding, _TaskBatchEncoding, _ModelBatchOutput, _TaskOutput
     TextDocument,
     TransformerSeq2SeqInputEncoding,
